Keen | Fixed Subheader
Description: Fixed subheader example

# Customer Relationship Management

New Order

### Fixed Subheader

Reports

### Author Sales

$64M

### Technologies

9.3M
HTML
CSS
Angular
+37%

### Total Orders

17M
Projects
Keen Admin Launch Day
To start a blog, think of a topic about and first brainstorm party is ways to write details
Progress
78%
First Milestone Achivement
To start a blog, think of a topic about and first brainstorm party is ways to write details
Progress
55%
Reached 50,000 sales
To start a blog, think of a topic about and first brainstorm party is ways to write details
Progress
24%
23 Dec

### Christmas Party

Bolton House
To start a blog, think of a topic about and first brainstorm party is ways to write details
+5
Join

### Recent Orders 32500 total

Sort By:
New Record

### Order Statistics

7,300
Total Orders
Mobile Games
Swift, Python, Java SDK
3,244 Orders
B2B2C Solutions
ASP.NET, Ruby, Python
962 Orders
HTML Templates
HTML, CSS, JS
2,750 Orders
Back-end Plugins
PHP, Ruby, C#, ASP.NET
890 Orders
Admin Software
Bootsrap, CSS, SCSS, AngularJS
1,644 Orders

### Notifications

02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
01:20 AM
New secyrity alert by Firewall & order to take
aktion on User Preferences
Security, Fieewall
02:30 PM
KeenThemes created new layout whith tens of
new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take
aktion on User references
Security, Fieewall
May 09, 2018
KeenThemes created new layout whith tens of
new options for Keen Admin panel
HTML,CSS,VueJS
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3
Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
Yestardey
FlyMore design mock-ups been uploadet by
designers Bob, Naomi, Richard
PSD, Sketch, AJ
Yestardey
FlyMore design mock-ups been uploadet by
designers Bob, Naomi, Richard
HTML,CSS,VueJS
02:30 PM
KeenThemes created new layout whith tens of
new options for Keen Admin panel
HTML,CSS,VueJS
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3
Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
Yestardey
FlyMore design mock-ups been uploadet by
designers Bob, Naomi, Richard
PSD, Sketch, AJ
01:20 AM
New secyrity alert by Firewall & order to take
aktion on User Preferences
Security, Fieewall
02:30 PM
KeenThemes created new layout whith tens of
new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take
aktion on User references
Security, Fieewall
May 09, 2018
KeenThemes created new layout whith tens of
new options for Keen Admin panel
HTML,CSS,VueJS
Yestardey
FlyMore design mock-ups been uploadet by
designers Bob, Naomi, Richard
HTML,CSS,VueJS
02:30 PM
KeenThemes created new layout whith tens of
new options for Keen Admin panel
HTML,CSS,VueJS

### Latest Uploads

All FILES
Keeg Design Reqs
95 MB
S.E.R Agreement
805 MB
FlyMore Screenshot
4 MB
ST.11 Dacuments
Unknown
XML AOL Data Fetchin
4 MB
Drag files here

### Recent Works

Quickly direct you useful content or people
HTML, CSS, JavaScripts
Get the point across
HTML, CSS, JavaScripts
Contain amazing email sign up form
HTML, CSS, JavaScripts
Tips on How to Write an About me page
HTML, CSS, JavaScripts
Get the point across
HTML, CSS, JavaScripts
Tips on How to Write an About me page
HTML, CSS, JavaScripts
Quickly direct you useful content or people
HTML, CSS, JavaScripts
Contain amazing email sign up form
HTML, CSS, JavaScripts
Contain amazing email sign up form
HTML, CSS, JavaScripts
Tips on How to Write an About me page
HTML, CSS, JavaScripts
Get the point across
HTML, CSS, JavaScripts
Tips on How to Write an About me page
HTML, CSS, JavaScripts
Get the point across
HTML, CSS, JavaScripts
Contain amazing email sign up form
HTML, CSS, JavaScripts
Get the point across
HTML, CSS, JavaScripts
Tips on How to Write an About me page
HTML, CSS, JavaScripts

### Latest Orders

Dark Blue Shoes - Limited Collection
SKU: 08451345264
$38.00 x 2
$76.00
Converse Sneakers - Red, Green & White
SKU: 08451345244
$92.00 x 1
$92.00
Merrell - Best Hiking Shoes
SKU: 08451345285
$224.00 x 1
$224.00
Ray Ban - Green Sunglasses
SKU: 08451345239
$109.00 x 3
$327.00
Preview Approve

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!